<!--
Copyright (C) 2023 Maxwell G <maxwell@gtmx.me>
SPDX-License-Identifier: MIT
-->

# libdnf5-shim

[![builds.sr.ht status](https://builds.sr.ht/~gotmax23/libdnf5-shim/commits/main.svg)](https://builds.sr.ht/~gotmax23/libdnf5-shim/commits/main?)

libdnf5 shim module for usage in virtualenvs.

Inspired by <https://github.com/packit/rpm-shim>.

## Links

- [libdnf5-shim project hub](https://sr.ht/~gotmax23/libdnf5-shim)
- [libdnf5-shim git.sr.ht repo](https://git.sr.ht/~gotmax23/libdnf5-shim)
- [libdnf5-shim tracker](https://todo.sr.ht/~gotmax23/libdnf5-shim)
- [libdnf5-shim mailing list][archives] ([~gotmax/libdnf5-shim@lists.sr.ht][mailto])

[archives]: https://lists.sr.ht/~gotmax23/libdnf5-shim
[mailto]: mailto:~gotmax/libdnf5-shim@lists.sr.ht

## Contributing

See [CONTRIBUTING.md](https://git.sr.ht/~gotmax23/libdnf5-shim/tree/main/item/CONTRIBUTING.md).

## License

This repository is licensed under

    SPDX-License-Identifer: MIT
